@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0204';
+our $VERSION = '0.0300';
 
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
@@ -214,13 +214,15 @@ sub _full_keys {
 sub _tt_sub {
     my ($self, $scale, $chords, $n) = @_;
 
-    my @notes = get_scale_notes('C', 'chromatic');
-    my %tritone = map { $notes[$_] => $notes[($_ + 6) % @notes] } 0 .. $#notes;
+    my @fnotes = get_scale_notes('C', 'chromatic', 0, 'b');
+    my @snotes = get_scale_notes('C', 'chromatic');
+    my %ftritone = map { $fnotes[$_] => $fnotes[($_ + 6) % @fnotes] } 0 .. $#fnotes;
+    my %stritone = map { $snotes[$_] => $snotes[($_ + 6) % @snotes] } 0 .. $#snotes;
 
     my $note;
     if ($n =~ /t/) {
         $n =~ s/t//;
-        $note = $tritone{ $scale->[$n - 1] };
+        $note = $ftritone{ $scale->[$n - 1] } || $stritone{ $scale->[$n - 1] };
         print "Tritone: $scale->[$n - 1] => $note\n" if $self->verbose;
     }
     else {
@@ -279,7 +281,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0204
+version 0.0300
 
 =head1 SYNOPSIS
 
